package hcw

import (
	"context"
	"github.com/gogf/gf/encoding/gjson"
	"github.com/gogf/gf/frame/g"
)

type OrderCreateReq struct {
	Order struct {
		Id              int    `json:"id"`
		ParentOrderSn   string `json:"parent_order_sn"`
		OrderSn         string `json:"order_sn"`
		ThirdOrderSn    string `json:"third_order_sn"`
		CreatedTime     string `json:"created_time"`
		OrderPayTime    string `json:"order_pay_time"`
		DispatchPrice   int    `json:"dispatch_price"`
		OrderTotalPrice int    `json:"order_total_price"`
		Remark          string `json:"remark"`
		RealName        string `json:"real_name"`
		Mobile          string `json:"mobile"`
		Provice         string `json:"provice"`
		City            string `json:"city"`
		District        string `json:"district"`
		Street          string `json:"street"`
		Address         string `json:"address"`
		ProvinceId      int    `json:"province_id"`
		CityId          int    `json:"city_id"`
		DistrictId      int    `json:"district_id"`
		StreetId        int    `json:"street_id"`
		SupplyType      string `json:"supply_type"`
	} `json:"order"`
	OrderGoodsDetail []*OrderGoodsDetailList `json:"order_goods_detail"`
}

type OrderGoodsDetailList struct {
	Id               int    `json:"id"`
	GoodsOrderSn     string `json:"goods_order_sn"`
	GoodsId          int    `json:"goods_id"`
	Total            int    `json:"total"`
	CreatedTime      int    `json:"created_time"`
	Thumb            string `json:"thumb"`
	Title            string `json:"title"`
	GoodsPrice       int    `json:"goods_price"`
	GoodsOptionId    int    `json:"goods_option_id"`
	GoodsOptionTitle string `json:"goods_option_title"`
	GoodsCode        string `json:"goods_code"`
}

type OrderCreateRes struct {
	Code    int    `json:"code"`
	Message string `json:"message"`
	Data    struct {
		OrderId int `json:"order_id"`
	} `json:"data"`
}

func (s *hcwClient) OrderCreate(ctx context.Context, req *OrderCreateReq) (res *OrderCreateRes, err error) {
	var method = "/api/v1/order"
	result, err := s.post(ctx, method, req)
	if nil != err {
		return
	}
	_ = gjson.New(result).Scan(&res)
	return
}

type OrderListReq struct {
	Page     string `json:"page"`      //页数
	PageSize string `json:"page_size"` //条数
}

type OrderListRes struct {
	Code    int    `json:"code"`
	Message string `json:"message"`
	Data    struct {
		List []struct {
			Id                 int         `json:"id"`
			OrderSn            string      `json:"order_sn"`
			ThirdOrderSn       string      `json:"third_order_sn"`
			ThreeOrderSn       string      `json:"three_order_sn"`
			OrderPrice         string      `json:"order_price"`
			OrderDiscountPrice string      `json:"order_discount_price"`
			OrderFreightPrice  string      `json:"order_freight_price"`
			OrderPayPrice      string      `json:"order_pay_price"`
			OrderPayTime       string      `json:"order_pay_time"`
			OrderFinishTime    interface{} `json:"order_finish_time"`
			OrderCancelTime    interface{} `json:"order_cancel_time"`
			OrderSendTime      interface{} `json:"order_send_time"`
			OrderType          int         `json:"order_type"`
			OrderStatus        int         `json:"order_status"`
			OrderPayStatus     int         `json:"order_pay_status"`
			SupplyType         string      `json:"supply_type"`
			OrderRemark        string      `json:"order_remark"`
			CreatedAt          string      `json:"created_at"`
			UpdatedAt          string      `json:"updated_at"`
		} `json:"list"`
		Total int `json:"total"`
	} `json:"data"`
}

func (s *hcwClient) OrderList(ctx context.Context, req *OrderCreateReq) (res *OrderListRes, err error) {
	var method = "/api/v1/order"
	result, err := s.get(ctx, method, req)
	if nil != err {
		return
	}
	_ = gjson.New(result).Scan(&res)
	return
}

type OrderDetailRes struct {
	Code    int    `json:"code"`
	Message string `json:"message"`
	Data    struct {
		Id                 int         `json:"id"`
		OrderSn            string      `json:"order_sn"`
		ThirdOrderSn       string      `json:"third_order_sn"`
		ThreeOrderSn       string      `json:"three_order_sn"`
		OrderPrice         string      `json:"order_price"`
		OrderDiscountPrice string      `json:"order_discount_price"`
		OrderFreightPrice  string      `json:"order_freight_price"`
		OrderPayPrice      string      `json:"order_pay_price"`
		OrderPayTime       string      `json:"order_pay_time"`
		OrderFinishTime    interface{} `json:"order_finish_time"`
		OrderCancelTime    interface{} `json:"order_cancel_time"`
		OrderSendTime      interface{} `json:"order_send_time"`
		OrderType          int         `json:"order_type"`
		OrderStatus        int         `json:"order_status"`
		OrderPayStatus     int         `json:"order_pay_status"`
		SupplyType         string      `json:"supply_type"`
		OrderRemark        string      `json:"order_remark"`
		CreatedAt          string      `json:"created_at"`
		UpdatedAt          string      `json:"updated_at"`
		DeletedAt          interface{} `json:"deleted_at"`
		OrderGoods         struct {
			OrderGoodsId  int         `json:"order_goods_id"`
			OrderSn       string      `json:"order_sn"`
			PlatOrderSn   interface{} `json:"plat_order_sn"`
			SupplyType    string      `json:"supply_type"`
			GoodsCode     string      `json:"goods_code"`
			GoodsName     string      `json:"goods_name"`
			GoodsNum      int         `json:"goods_num"`
			GoodsPrice    string      `json:"goods_price"`
			GoodsBuyPrice string      `json:"goods_buy_price"`
			GoodsPayPrice string      `json:"goods_pay_price"`
			GoodsSkuName  string      `json:"goods_sku_name"`
			GoodsSkuNo    string      `json:"goods_sku_no"`
			GoodsImage    string      `json:"goods_image"`
			CreatedAt     string      `json:"created_at"`
			UpdatedAt     string      `json:"updated_at"`
			DeletedAt     interface{} `json:"deleted_at"`
		} `json:"order_goods"`
		OrderAddress struct {
			OrderAddressId      int         `json:"order_address_id"`
			OrderSn             string      `json:"order_sn"`
			ReceiveName         string      `json:"receive_name"`
			ReceiveMobile       string      `json:"receive_mobile"`
			ReceiveAddress      string      `json:"receive_address"`
			ReceiveProvinceId   string      `json:"receive_province_id"`
			ReceiveCityId       string      `json:"receive_city_id"`
			ReceiveAreaId       string      `json:"receive_area_id"`
			ReceiverStreetId    string      `json:"receiver_street_id"`
			ReceiveProvinceName string      `json:"receive_province_name"`
			ReceiveCityName     string      `json:"receive_city_name"`
			ReceiveAreaName     string      `json:"receive_area_name"`
			ReceiveStreetName   string      `json:"receive_street_name"`
			CreatedAt           string      `json:"created_at"`
			UpdatedAt           string      `json:"updated_at"`
			DeletedAt           interface{} `json:"deleted_at"`
		} `json:"order_address"`
		OrderLogistics interface{} `json:"order_logistics"`
	} `json:"data"`
}

func (s *hcwClient) OrderDetail(ctx context.Context, orderSn string) (res *OrderDetailRes, err error) {
	var method = "/api/v1/order/" + orderSn
	result, err := s.get(ctx, method, g.Map{})
	if nil != err {
		return
	}
	_ = gjson.New(result).Scan(&res)
	return
}

type OrderCheckReq struct {
	GoodsId    int    `json:"goods_id"`
	BuyNum     int    `json:"buy_num"`
	SupplyType string `json:"supply_type"`
}

type OrderCheckRes struct {
	Code    int    `json:"code"`
	Message string `json:"message"`
	Data    struct {
		OrderId int `json:"order_id"`
	} `json:"data"`
}

func (s *hcwClient) OrderCheck(ctx context.Context, req *OrderCheckReq) (res *OrderCheckRes, err error) {
	var method = "/api/v1/order/check"
	result, err := s.post(ctx, method, req)
	if nil != err {
		return
	}
	_ = gjson.New(result).Scan(&res)
	return
}
